@@ -516,7 +516,14 @@ try {
                 throw new Exception('Permission denied');
             }
             
-            $result = $schedule->update($_POST);
+            // Process checkbox value
+            $updateData = $_POST;
+            if (isset($updateData['is_active'])) {
+                // Convert checkbox value to integer (0 or 1)
+                $updateData['is_active'] = ($updateData['is_active'] === 'on' || $updateData['is_active'] === '1') ? 1 : 0;
+            }
+            
+            $result = $schedule->update($updateData);
             
             if ($result) {
                 echo json_encode(['success' => true, 'message' => 'Schedule updated successfully']);
