@@ -465,52 +465,60 @@ class BackupEngine {
             }
         }
         
-        // Generate backup name if not provided
-        if (!$backupName) {
-            $backupName = "wp_{$site['domain']}_" . date('Y-m-d_H-i-s');
+        $target = new BackupTarget($this->db, $targetId);
+        if (!$target->canAccess($site['user'])) {
+            return [
+                'success' => false,
+                'error' => "Access denied to backup target"
+            ];
         }
-        
-        try {
-            // Create site backup (files)
-            $siteBackupResult = $this->createSiteBackup($site['user'], $site['domain'], $targetId);
 
-            // Create database backup only if database name is available
-            $dbBackupResult = null;
-            if (!empty($site['database_name'])) {
-                $dbBackupResult = $this->createDatabaseBackup($site['user'], $site['database_name'], $targetId);
-            } else {
-                // Log warning but continue with file backup only
-                error_log("Warning: WordPress site {$site['domain']} has no database configured, creating file backup only");
-                $dbBackupResult = ['success' => true, 'backup_id' => null, 'size' => 0];
-            }
-            
-            // Create combined backup record
+        // Generate backup name if not provided - include domain for clarity
+        // Sanitize domain name for filesystem compatibility
+        $safeDomain = preg_replace('/[^a-zA-Z0-9.-]/', '_', $site['domain']);
+        if (!$backupName) {
+            $backupName = "wp_{$safeDomain}_" . date('Y-m-d_H-i-s');
+        } else if (strpos($backupName, $safeDomain) === false) {
+            // If custom name provided but doesn't include domain, add it
+            $backupName = "{$safeDomain}_{$backupName}";
+        }
+
+        $remotePath = "{$site['user']}/wordpress/" . $backupName . '.tar.gz';
+
+        try {
+            // Create backup history record with pending status
             $history = new BackupHistory($this->db);
-            $combinedBackupId = $history->create([
+            $backupId = $history->create([
                 'target_id' => $targetId,
                 'user' => $site['user'],
                 'backup_type' => 'wordpress',
                 'backup_name' => $backupName,
-                'backup_path' => "wordpress/{$site['domain']}/",
-                'backup_size' => ($siteBackupResult['size'] ?? 0) + ($dbBackupResult['size'] ?? 0),
-                'status' => 'completed',
+                'backup_path' => $remotePath,
+                'status' => 'pending',
                 'metadata' => [
                     'wordpress_site_id' => $siteId,
                     'domain' => $site['domain'],
                     'database' => $site['database_name'] ?? null,
-                    'site_backup_id' => $siteBackupResult['backup_id'] ?? null,
-                    'db_backup_id' => $dbBackupResult['backup_id'] ?? null,
                     'wp_version' => $site['wp_version'] ?? null,
                     'source_path' => "/docker/users/{$site['user']}/{$site['domain']}"
                 ]
             ]);
-            
+
+            if (!$backupId) {
+                return [
+                    'success' => false,
+                    'error' => "Failed to create backup record"
+                ];
+            }
+
+            // Trigger background processing
+            $this->triggerBackgroundProcessing();
+
             return [
                 'success' => true,
-                'backup_id' => $combinedBackupId,
-                'site_backup_id' => $siteBackupResult['backup_id'] ?? null,
-                'db_backup_id' => $dbBackupResult['backup_id'] ?? null,
-                'message' => "WordPress backup created successfully"
+                'backup_id' => $backupId,
+                'backup_name' => $backupName,
+                'status' => 'pending'
             ];
             
         } catch (Exception $e) {
