@@ -47,6 +47,9 @@ class BackupJob {
                 case 'database':
                     $this->processDatabaseBackup($history, $data);
                     break;
+                case 'wordpress':
+                    $this->processWordPressBackup($history, $data);
+                    break;
                 default:
                     throw new Exception("Unknown backup type: " . $data['backup_type']);
             }
@@ -103,14 +106,49 @@ class BackupJob {
         $metadata = is_array($data['metadata']) ? $data['metadata'] : json_decode($data['metadata'], true);
         $database = $metadata['database'];
         $user = $data['user'];
-        
+
         // Step 1: Create SQL dump
         $tempFile = $this->tempDir . '/' . $data['backup_name'] . '.sql.gz';
         $this->createDatabaseDump($database, $tempFile);
-        
+
         // Step 2: Upload to storage
         $this->uploadToStorage($history, $data, $tempFile);
-        
+
+        // Step 3: Clean up temp file
+        if (file_exists($tempFile)) {
+            unlink($tempFile);
+        }
+    }
+
+    private function processWordPressBackup($history, $data) {
+        $metadata = is_array($data['metadata']) ? $data['metadata'] : json_decode($data['metadata'], true);
+        $sourcePath = $metadata['source_path'];
+        $database = $metadata['database'] ?? null;
+        $domain = $metadata['domain'];
+        $user = $data['user'];
+
+        // Validate user and domain for security
+        if (!preg_match('/^[a-zA-Z0-9_-]+$/', $user)) {
+            throw new Exception("Invalid user format");
+        }
+        if (!preg_match('/^[a-zA-Z0-9.-]+$/', $domain)) {
+            throw new Exception("Invalid domain format");
+        }
+
+        // Validate source path is within expected directory structure
+        $expectedBasePath = "/docker/users/$user/";
+        $realSourcePath = realpath($sourcePath);
+        if (!$realSourcePath || strpos($realSourcePath, $expectedBasePath) !== 0) {
+            throw new Exception("Invalid source path");
+        }
+
+        // Step 1: Create combined WordPress archive
+        $tempFile = $this->tempDir . '/' . $data['backup_name'] . '.tar.gz';
+        $this->createWordPressArchive($sourcePath, $database, $tempFile, $user, $domain);
+
+        // Step 2: Upload to storage
+        $this->uploadToStorage($history, $data, $tempFile);
+
         // Step 3: Clean up temp file
         if (file_exists($tempFile)) {
             unlink($tempFile);
@@ -201,6 +239,11 @@ class BackupJob {
     }
     
     private function createDatabaseDump($database, $tempFile) {
+        // Validate database name for security (prevent SQL injection and command injection)
+        if (!preg_match('/^[a-zA-Z0-9_]+$/', $database)) {
+            throw new Exception("Invalid database name format");
+        }
+
         // Get database credentials
         $mysql = new \mysqlmgmt();
         $host = '127.0.0.1';
@@ -271,7 +314,119 @@ class BackupJob {
             throw new Exception("Compressed database dump file is empty or doesn't exist");
         }
     }
-    
+
+    private function createWordPressArchive($sourcePath, $database, $tempFile, $user, $domain) {
+        if (!is_dir($sourcePath)) {
+            throw new Exception("WordPress site directory not found: $sourcePath");
+        }
+
+        // Create temporary directory for organizing the backup content
+        // Use random_bytes for cryptographically secure temporary directory name
+        $randomSuffix = bin2hex(random_bytes(16));
+        $tempWorkDir = $this->tempDir . '/wp_backup_' . $randomSuffix;
+        if (!mkdir($tempWorkDir, 0700, true)) { // More restrictive permissions
+            throw new Exception("Failed to create temporary work directory");
+        }
+
+        try {
+            // Step 1: Create site files archive
+            $siteArchivePath = $tempWorkDir . '/site.tar.gz';
+            $this->createSiteArchiveForWordPress($sourcePath, $siteArchivePath, $user, $domain);
+
+            // Step 2: Create database dump if database exists
+            $dbDumpPath = null;
+            if (!empty($database)) {
+                $dbDumpPath = $tempWorkDir . '/database.sql.gz';
+                $this->createDatabaseDump($database, $dbDumpPath);
+            }
+
+            // Step 3: Create manifest file with backup information
+            $manifestPath = $tempWorkDir . '/backup-manifest.json';
+            $manifest = [
+                'backup_type' => 'wordpress',
+                'domain' => $domain,
+                'user' => $user,
+                'created_at' => date('Y-m-d H:i:s'),
+                'files' => [
+                    'site' => 'site.tar.gz',
+                    'database' => $database ? 'database.sql.gz' : null
+                ],
+                'database_name' => $database
+            ];
+            file_put_contents($manifestPath, json_encode($manifest, JSON_PRETTY_PRINT));
+
+            // Step 4: Create final combined archive
+            $filesToArchive = ['backup-manifest.json', 'site.tar.gz'];
+            if ($dbDumpPath && file_exists($dbDumpPath)) {
+                $filesToArchive[] = 'database.sql.gz';
+            }
+
+            // Use tar with gzip compression
+            $filesArg = implode(' ', array_map('escapeshellarg', $filesToArchive));
+            $command = "cd " . escapeshellarg($tempWorkDir) . " && tar -czf " . escapeshellarg($tempFile) . " " . $filesArg;
+
+            exec($command, $output, $returnCode);
+
+            if ($returnCode !== 0) {
+                throw new Exception("Failed to create WordPress archive: " . implode("\n", $output));
+            }
+
+            if (!file_exists($tempFile) || filesize($tempFile) === 0) {
+                throw new Exception("WordPress archive file is empty or doesn't exist");
+            }
+
+        } finally {
+            // Clean up temporary work directory
+            if (is_dir($tempWorkDir)) {
+                $this->removeDirectory($tempWorkDir);
+            }
+        }
+    }
+
+    private function createSiteArchiveForWordPress($sourcePath, $tempFile, $user, $domain) {
+        // This is similar to createSiteArchive but creates the archive directly in the specified location
+        $userDir = dirname($sourcePath);
+        $userName = basename($userDir);
+        $domainName = basename($sourcePath);
+
+        // Use pigz for parallel compression if available, otherwise fall back to gzip
+        if (shell_exec('which pigz 2>/dev/null')) {
+            // Create tar without compression, then compress with pigz
+            $tarFile = $tempFile . '.tar';
+            $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -cf " . escapeshellarg($tarFile) . " " . escapeshellarg($userName . "/" . $domainName) . " && pigz -6 -c " . escapeshellarg($tarFile) . " > " . escapeshellarg($tempFile) . " && rm -f " . escapeshellarg($tarFile);
+        } else {
+            // Fall back to standard tar with gzip compression
+            $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/" . $domainName);
+        }
+
+        exec($command, $output, $returnCode);
+
+        if ($returnCode !== 0) {
+            throw new Exception("Failed to create site archive: " . implode("\n", $output));
+        }
+
+        if (!file_exists($tempFile) || filesize($tempFile) === 0) {
+            throw new Exception("Site archive file is empty or doesn't exist");
+        }
+    }
+
+    private function removeDirectory($dir) {
+        if (!is_dir($dir)) {
+            return;
+        }
+
+        $files = array_diff(scandir($dir), ['.', '..']);
+        foreach ($files as $file) {
+            $path = $dir . '/' . $file;
+            if (is_dir($path)) {
+                $this->removeDirectory($path);
+            } else {
+                unlink($path);
+            }
+        }
+        rmdir($dir);
+    }
+
     private function uploadToStorage($history, $data, $tempFile) {
         $target = new BackupTarget($this->db, $data['target_id']);
         $storage = new BackupStorage($target->getCredentials());
